@@ -13,8 +13,7 @@ Important note regarding shortcuts:
         Ctrl + Alt + Q, W, F, G, Y, X, C, V, B, N
 """
 
-import os, sys
-import os.path as osp
+import os, sys, os.path as osp
 from datetime import date
 from PyQt4.QtGui import QLabel, QIcon, QPixmap, QFont, QFontDatabase
 
@@ -78,11 +77,13 @@ DEFAULTS = [
               'vertical_tabs': False,
               'animated_docks': True,
               'window/size': (1260, 740),
+              'window/position': (10, 10),
               'window/is_maximized': False,
               'window/is_fullscreen': False,
-              'window/position': (10, 10),
               'lightwindow/size': (650, 400),
               'lightwindow/position': (30, 30),
+              'lightwindow/is_maximized': False,
+              'lightwindow/is_fullscreen': False,
               }),
             ('editor_appearance',
              {
@@ -101,6 +102,16 @@ DEFAULTS = [
             ('shell_appearance',
              {
               'cursor/width': 2,
+              'calltips/font/family': MONOSPACE,
+              'calltips/font/size': SMALL,
+              'calltips/font/italic': False,
+              'calltips/font/bold': False,
+              'calltips/size': 600,
+              'completion/font/family': MONOSPACE,
+              'completion/font/size': SMALL,
+              'completion/font/italic': False,
+              'completion/font/bold': False,
+              'completion/size': (300, 180),
               }),
             ('internal_console',
              {
@@ -124,7 +135,7 @@ DEFAULTS = [
             ('console',
              {
               'shortcut': "Ctrl+Shift+C",
-              'max_line_count': 300,
+              'max_line_count': 10000,
               'font/family': MONOSPACE,
               'font/size': MEDIUM,
               'font/italic': False,
@@ -147,6 +158,8 @@ DEFAULTS = [
               'umd/namelist': ['guidata', 'guiqwt'],
               'light_background': True,
               'ipython_set_color': True,
+              'remove_pyqt_inputhook': os.name == 'nt',
+              'ignore_sip_setapi_errors': True,
               }),
             ('variable_explorer',
              {
@@ -300,13 +313,22 @@ DEV = not __file__.startswith(sys.prefix)
 DEV = False
 from spyderlib import __version__
 _subfolder = '.spyder%s' % __version__.split('.')[0]
-CONF = UserConfig('spyder', defaults=DEFAULTS, load=(not DEV),
-                  version='2.0.6', subfolder=_subfolder, backup=True)
+CONF = UserConfig('spyder', defaults=DEFAULTS, load=(not DEV), version='2.0.6',
+                  subfolder=_subfolder, backup=True, raw_mode=True)
 # Removing old .spyder.ini location:
 old_location = osp.join(get_home_dir(), '.spyder.ini')
 if osp.isfile(old_location):
     os.remove(old_location)
 
+
+# Translation support
+if CONF.get('main', 'translation'):
+    from spyderlib.utils.translations import get_translation
+    _ = get_translation("spyderlib")
+else:
+    _ = lambda x: x
+
+
 def get_conf_path(filename=None):
     """Return absolute path for configuration file with specified filename"""
     conf_dir = osp.join(get_home_dir(), _subfolder)
@@ -424,7 +446,7 @@ def reset_shortcuts():
     CONF.remove_section('shortcuts')
 
 
-from spyderlib.widgets.codeeditor.syntaxhighlighters import (
+from spyderlib.widgets.sourcecode.syntaxhighlighters import (
                                 COLOR_SCHEME_KEYS, COLOR_SCHEME_NAMES, COLORS)
 def get_color_scheme(name):
     """Get syntax color scheme"""
