@@ -6,10 +6,10 @@
 
 """Internal Console Plugin"""
 
-# pylint: disable-msg=C0103
-# pylint: disable-msg=R0903
-# pylint: disable-msg=R0911
-# pylint: disable-msg=R0201
+# pylint: disable=C0103
+# pylint: disable=R0903
+# pylint: disable=R0911
+# pylint: disable=R0201
 
 from spyderlib.qt.QtGui import (QVBoxLayout, QFileDialog, QFontDialog,
                                 QInputDialog, QLineEdit, QMenu)
@@ -40,7 +40,8 @@ class Console(SpyderPluginWidget):
     """
     CONF_SECTION = 'internal_console'
     def __init__(self, parent=None, namespace=None, commands=[], message="",
-                 debug=False, exitfunc=None, profile=False, multithreaded=True):
+                 debug=False, exitfunc=None, profile=False,
+                 multithreaded=False):
         
         self.dialog_manager = DialogManager()
 
