@@ -6,10 +6,10 @@
 
 """Shortcut management"""
 
-from PyQt4.QtGui import (QVBoxLayout, QWidget, QComboBox, QItemDelegate,
-                         QTableView, QMessageBox, QPushButton)
-from PyQt4.QtCore import (Qt, QSize, QAbstractTableModel, QVariant, QModelIndex,
-                          SIGNAL)
+from spyderlib.qt.QtGui import (QVBoxLayout, QComboBox, QItemDelegate,
+                                QTableView, QMessageBox, QPushButton)
+from spyderlib.qt.QtCore import (Qt, QSize, QAbstractTableModel, QVariant,
+                                 QModelIndex, SIGNAL)
 
 import sys
 
@@ -18,8 +18,7 @@ STDOUT = sys.stdout
 
 # Local imports
 from spyderlib.config import (get_icon, get_shortcut, set_shortcut,
-                              iter_shortcuts, reset_shortcuts)
-from spyderlib.utils.qthelpers import translate
+                              iter_shortcuts, reset_shortcuts, _)
 from spyderlib.plugins.configdialog import GeneralConfigPage
 
 
@@ -155,19 +154,17 @@ class ShortcutsModel(QAbstractTableModel):
             return QVariant()
         if orientation == Qt.Horizontal:
             if section == CONTEXT:
-                return QVariant(translate("ShortcutsConfigPage",
-                                          "Context"))
+                return QVariant(_("Context"))
             elif section == NAME:
-                return QVariant(translate("ShortcutsConfigPage",
-                                          "Name"))
+                return QVariant(_("Name"))
             elif section == MOD1:
-                return QVariant(translate("ShortcutsConfigPage", "Mod1"))
+                return QVariant(_("Mod1"))
             elif section == MOD2:
-                return QVariant(translate("ShortcutsConfigPage", "Mod2"))
+                return QVariant(_("Mod2"))
             elif section == MOD3:
-                return QVariant(translate("ShortcutsConfigPage", "Mod3"))
+                return QVariant(_("Mod3"))
             elif section == KEY:
-                return QVariant(translate("ShortcutsConfigPage", "Key"))
+                return QVariant(_("Key"))
         return QVariant()
 
     def rowCount(self, index=QModelIndex()):
@@ -259,17 +256,18 @@ class ShortcutsDelegate(QItemDelegate):
             QItemDelegate.setModelData(self, editor, model, index)
 
 
-class ShortcutsTable(QWidget):
+class ShortcutsTable(QTableView):
     def __init__(self, parent=None):
-        QWidget.__init__(self, parent)
+        QTableView.__init__(self, parent)
         self.model = ShortcutsModel()
-        self.view = QTableView(self)
-        self.view.setModel(self.model)
-        self.view.setItemDelegate(ShortcutsDelegate(self))
-        layout = QVBoxLayout()
-        layout.addWidget(self.view)
-        self.setLayout(layout)
+        self.setModel(self.model)
+        self.setItemDelegate(ShortcutsDelegate(self))
         self.load_shortcuts()
+                     
+    def adjust_cells(self):
+        self.resizeColumnsToContents()
+#        self.resizeRowsToContents()
+        self.horizontalHeader().setStretchLastSection(True)
         
     def load_shortcuts(self):
         shortcuts = []
@@ -279,7 +277,7 @@ class ShortcutsTable(QWidget):
         shortcuts = sorted(shortcuts, key=lambda x: x.context+x.name)
         self.model.shortcuts = shortcuts
         self.model.reset()
-        self.view.resizeColumnsToContents()
+        self.adjust_cells()
 
     def check_shortcuts(self):
         """Check shortcuts for conflicts"""
@@ -298,12 +296,9 @@ class ShortcutsTable(QWidget):
             self.parent().emit(SIGNAL('show_this_page()'))
             cstr = "\n".join(['%s <---> %s' % (sh1, sh2)
                               for sh1, sh2 in conflicts])
-            QMessageBox.warning(self,
-                                translate("ShortcutsConfigPage", "Conflicts"),
-                                translate("ShortcutsConfigPage",
-                                          "The following conflicts have been "
-                                          "detected:")+"\n"+cstr,
-                                QMessageBox.Ok)
+            QMessageBox.warning(self, _( "Conflicts"),
+                                _("The following conflicts have been "
+                                  "detected:")+"\n"+cstr, QMessageBox.Ok)
         
     def save_shortcuts(self):
         self.check_shortcuts()
@@ -314,7 +309,7 @@ class ShortcutsTable(QWidget):
 class ShortcutsConfigPage(GeneralConfigPage):
     CONF_SECTION = "shortcuts"
     def get_name(self):
-        return self.tr("Keyboard shortcuts")
+        return _("Keyboard shortcuts")
     
     def get_icon(self):
         return get_icon("genprefs.png")
@@ -326,7 +321,7 @@ class ShortcutsConfigPage(GeneralConfigPage):
                      lambda i1, i2: self.has_been_modified())
         vlayout = QVBoxLayout()
         vlayout.addWidget(self.table)
-        reset_btn = QPushButton(self.tr("Reset to default values"))
+        reset_btn = QPushButton(_("Reset to default values"))
         self.connect(reset_btn, SIGNAL('clicked()'), self.reset_to_default)
         vlayout.addWidget(reset_btn)
         self.setLayout(vlayout)
