@@ -317,6 +317,7 @@ class MainWindow(QMainWindow):
         self.already_closed = False
         
         self.window_size = None
+        self.window_position = None
         self.last_window_state = None
         self.last_plugin = None
         self.fullscreen_flag = None # isFullscreen does not work as expected
@@ -832,9 +833,12 @@ class MainWindow(QMainWindow):
             for toolbar in (self.run_toolbar, self.edit_toolbar):
                 toolbar.close()
             self.projectexplorer.dockwidget.close()
+        
+        self.setWindowState(Qt.WindowNoState)
         self.resize( QSize(width, height) )
         self.window_size = self.size()
         self.move( QPoint(posx, posy) )
+        self.window_position = self.pos()
         
         if not self.light:
             # Window layout
@@ -978,6 +982,12 @@ class MainWindow(QMainWindow):
             self.window_size = self.size()
         QMainWindow.resizeEvent(self, event)
         
+    def moveEvent(self, event):
+        """Reimplement Qt method"""
+        if not self.isMaximized() and not self.fullscreen_flag:
+            self.window_position = self.pos()
+        QMainWindow.moveEvent(self, event)
+        
     def closing(self, cancelable=False):
         """Exit tasks"""
         if self.already_closed:
@@ -987,7 +997,7 @@ class MainWindow(QMainWindow):
         CONF.set('main', prefix+'size', (size.width(), size.height()))
         CONF.set('main', prefix+'is_maximized', self.isMaximized())
         CONF.set('main', prefix+'is_fullscreen', self.isFullScreen())
-        pos = self.pos()
+        pos = self.window_position
         CONF.set('main', prefix+'position', (pos.x(), pos.y()))
         if not self.light:
             self.maximize_dockwidget(restore=True)# Restore non-maximized layout
@@ -1119,7 +1129,7 @@ class MainWindow(QMainWindow):
             (&copy; 2006-2007 Everaldo Coelho)
             <p>Spyder's community:
             <ul><li>Bug reports and feature requests: 
-            <a href="http://spyderlib.googlecode.com">Google Code</a>
+            <a href="http://spyder.googlecode.com">Google Code</a>
             </li><li>Discussions around the project: 
             <a href="http://groups.google.com/group/spyderlib">Google Group</a>
             </li></ul>
@@ -1499,7 +1509,7 @@ def main():
 
     if CONF.get('main', 'crash', False):
         CONF.set('main', 'crash', False)
-        issues_link = 'http://code.google.com/p/spyderlib/issues/list'
+        issues_link = 'http://code.google.com/p/spyder/issues/list'
         group_link = 'http://groups.google.com/group/spyderlib'
         QMessageBox.information(None, "Spyder",
             u"Spyder crashed during last session.<br><br>"
