@@ -151,26 +151,35 @@ def get_error_match(text):
     import re
     return re.match(r'  File "(.*)", line (\d*)', text)
 
+def log_time(fd):
+    timestr = "Logging time: %s" % time.ctime(time.time())
+    print >>fd, "="*len(timestr)
+    print >>fd, timestr
+    print >>fd, "="*len(timestr)
+    print >>fd, ""
 
 def log_last_error(fname, context=None):
     """Log last error in filename *fname* -- *context*: string (optional)"""
     out = StringIO.StringIO()
     traceback.print_exc(file=out)
-    errors = open(fname, 'a')
-    timestr = "Logging time: %s" % time.ctime(time.time())
-    print >>errors, "="*len(timestr)
-    print >>errors, timestr
-    print >>errors, "="*len(timestr)
-    print >>errors, ""
+    fd = open(fname, 'a')
+    log_time(fd)
     if context:
-        print >>errors, "Context"
-        print >>errors, "-------"
-        print >>errors, ""
-        print >>errors, context
-        print >>errors, ""
-        print >>errors, "Traceback"
-        print >>errors, "---------"
-        print >>errors, ""
-    traceback.print_exc(file=errors)
-    print >>errors, ""
-    print >>errors, ""
+        print >>fd, "Context"
+        print >>fd, "-------"
+        print >>fd, ""
+        print >>fd, context
+        print >>fd, ""
+        print >>fd, "Traceback"
+        print >>fd, "---------"
+        print >>fd, ""
+    traceback.print_exc(file=fd)
+    print >>fd, ""
+    print >>fd, ""
+
+def log_dt(fname, context, t0):
+    fd = open(fname, 'a')
+    log_time(fd)
+    print >>fd, "%s: %d ms" % (context, 10*round(1e2*(time.time()-t0)))
+    print >>fd, ""
+    print >>fd, ""
