@@ -9,11 +9,11 @@
 import os.path as osp
 import os, webbrowser
 
-from PyQt4.QtGui import (QAction, QStyle, QWidget, QIcon, QApplication, QLabel,
-                         QVBoxLayout, QHBoxLayout, QLineEdit, QKeyEvent, QMenu,
-                         QKeySequence, QToolButton)
-from PyQt4.QtCore import (SIGNAL, QVariant, QObject, Qt, QLocale, QTranslator,
-                          QLibraryInfo)
+from spyderlib.qt.QtGui import (QAction, QStyle, QWidget, QIcon, QApplication,
+                                QLabel, QVBoxLayout, QHBoxLayout, QLineEdit,
+                                QKeyEvent, QMenu, QKeySequence, QToolButton)
+from spyderlib.qt.QtCore import (SIGNAL, QVariant, QObject, Qt, QLocale,
+                                 QTranslator, QLibraryInfo)
 
 # Local import
 from spyderlib.config import get_icon, DATA_PATH, get_spyderplugins, PLUGIN_PATH
@@ -29,77 +29,69 @@ from spyderlib.utils import programs
 #    self.connect(self.listwidget, SIGNAL('option_changed'),
 #                 lambda *args: self.emit(SIGNAL('option_changed'), *args))
 
-TRANSLATORS = []
-
-QAPPLICATION = None
-
 def qapplication(translate=True):
     """
     Return QApplication instance
     Creates it if it doesn't already exist
     """
-    global QAPPLICATION
-    if QApplication.startingUp():
-        QAPPLICATION = QApplication([])
-        if translate:
-            install_translators(QAPPLICATION)
-    elif QAPPLICATION is None:
-        QAPPLICATION = QApplication.instance()
-    return QAPPLICATION
+    app = QApplication.instance()
+    if not app:
+        app = QApplication([])
+    if translate:
+        install_translator(app)
+    return app
 
-def install_translators(qapp):
-    """Install translators to the QApplication instance"""
-    global TRANSLATORS
-    locale = QLocale.system().name()
-    # Qt-specific translator
-    qt_translator = QTranslator()
-    TRANSLATORS.append(qt_translator) # Keep reference alive
-    paths = QLibraryInfo.location(QLibraryInfo.TranslationsPath)
-    if qt_translator.load("qt_"+locale, paths):
-        qapp.installTranslator(qt_translator)
-    # Spyder-specific translator
-    app_translator = QTranslator()
-    TRANSLATORS.append(app_translator) # Keep reference alive
-    if app_translator.load("spyder_"+locale, DATA_PATH):
-        qapp.installTranslator(app_translator)
-    # Load 3rd-party plugin translators
-    for modname in get_spyderplugins(prefix='p_', extension='.py'):
-        plugin_translator = QTranslator()
-        TRANSLATORS.append(plugin_translator)
-        if plugin_translator.load(modname+"_"+locale, PLUGIN_PATH):
-            qapp.installTranslator(plugin_translator)
-
-def translate(context, string):
-    """Translation"""
-    return QApplication.translate(context, string)
+QT_TRANSLATOR = None
+def install_translator(qapp):
+    """Install Qt translator to the QApplication instance"""
+    global QT_TRANSLATOR
+    if QT_TRANSLATOR is None:
+        locale = QLocale.system().name()
+        # Qt-specific translator
+        qt_translator = QTranslator()
+        paths = QLibraryInfo.location(QLibraryInfo.TranslationsPath)
+        if qt_translator.load("qt_"+locale, paths):
+            QT_TRANSLATOR = qt_translator # Keep reference alive
+    if QT_TRANSLATOR is not None:
+        qapp.installTranslator(QT_TRANSLATOR)
 
 def keybinding(attr):
     """Return keybinding"""
     ks = getattr(QKeySequence, attr)
     return QKeySequence.keyBindings(ks)[0].toString()
 
+def _process_mime_path(path, extlist):
+    if path.startswith(r"file://"):
+        if os.name == 'nt':
+            # On Windows platforms, a local path reads: file:///c:/...
+            # and a UNC based path reads like: file://server/share
+            if path.startswith(r"file:///"): # this is a local path
+                path=path[8:]
+            else: # this is a unc path
+                path = path[5:]
+        else:
+            path = path[7:]
+    if osp.exists(path):
+        if extlist is None or osp.splitext(path)[1] in extlist:
+            return path
+
 def mimedata2url(source, extlist=None):
     """
     Extract url list from MIME data
     extlist: for example ('.py', '.pyw')
     """
+    pathlist = []
     if source.hasUrls():
-        pathlist = []
         for url in source.urls():
-            path = unicode(url.toString())
-            if path.startswith(r"file://"):
-                if os.name == 'nt':
-                    # On Windows platforms, a local path reads: file:///c:/...
-                    # and a UNC based path reads like: file://server/share
-                    if path.startswith(r"file:///"): # this is a local path
-                        path=path[8:]
-                    else: # this is a unc path
-                        path = path[5:]
-                else:
-                    path = path[7:]
-            if osp.exists(path):
-                if extlist is None or osp.splitext(path)[1] in extlist:
-                    pathlist.append(path)
+            path = _process_mime_path(unicode(url.toString()), extlist)
+            if path is not None:
+                pathlist.append(path)
+    elif source.hasText():
+        for rawpath in unicode(source.text()).splitlines():
+            path = _process_mime_path(rawpath, extlist)
+            if path is not None:
+                pathlist.append(path)
+    if pathlist:
         return pathlist
 
 def keyevent2tuple(event):
