@@ -6,10 +6,10 @@
 
 """Editor Widget"""
 
-# pylint: disable-msg=C0103
-# pylint: disable-msg=R0903
-# pylint: disable-msg=R0911
-# pylint: disable-msg=R0201
+# pylint: disable=C0103
+# pylint: disable=R0903
+# pylint: disable=R0911
+# pylint: disable=R0201
 
 from spyderlib.qt.QtGui import (QVBoxLayout, QFileDialog, QMessageBox, QMenu,
                                 QFont, QAction, QApplication, QWidget,
@@ -220,7 +220,7 @@ class CodeAnalysisThread(QThread):
 
 class ToDoFinderThread(QThread):
     """TODO finder thread"""
-    PATTERN = r"# ?TODO ?:[^#]*|# ?FIXME ?:[^#]*|# ?XXX ?:?[^#]*|# ?HINT ?:?[^#]*|# ?TIP ?:?[^#]*"
+    PATTERN = r"# ?TODO ?:?[^#]*|# ?FIXME ?:?[^#]*|# ?XXX ?:?[^#]*|# ?HINT ?:?[^#]*|# ?TIP ?:?[^#]*"
     def __init__(self, parent):
         QThread.__init__(self, parent)
         self.text = None
