@@ -12,16 +12,16 @@ import sys, os, os.path as osp, socket
 STDOUT = sys.stdout
 STDERR = sys.stderr
 
-from PyQt4.QtGui import (QApplication, QMessageBox, QSplitter, QFileDialog,
-                         QMenu)
-from PyQt4.QtCore import QProcess, SIGNAL, QString, Qt
+from spyderlib.qt.QtGui import (QApplication, QMessageBox, QSplitter,
+                                QFileDialog, QMenu)
+from spyderlib.qt.QtCore import QProcess, SIGNAL, QString, Qt
 
 # Local imports
 from spyderlib.utils.qthelpers import (create_toolbutton, create_action,
                                        get_std_icon, DialogManager, add_actions)
 from spyderlib.utils.environ import RemoteEnvDialog
 from spyderlib.utils.programs import split_clo
-from spyderlib.config import get_icon
+from spyderlib.config import get_icon, _
 from spyderlib.widgets.shell import PythonShellWidget
 from spyderlib.widgets.externalshell import startup
 from spyderlib.widgets.externalshell.namespacebrowser import NamespaceBrowser
@@ -142,7 +142,7 @@ class ExternalPythonShell(ExternalShellBase):
                  umd_enabled=True, umd_namelist=[], umd_verbose=True,
                  monitor_enabled=True, mpl_patch_enabled=True,
                  mpl_backend='Qt4Agg', ets_backend='qt4',
-                 remove_pyqt_inputhook=True,
+                 remove_pyqt_inputhook=True, ignore_sip_setapi_errors=True,
                  autorefresh_timeout=3000, autorefresh_state=True,
                  light_background=True, menu_actions=None,
                  show_buttons_inside=True, show_elapsed_time=True):
@@ -165,6 +165,7 @@ class ExternalPythonShell(ExternalShellBase):
         self.mpl_backend = mpl_backend
         self.ets_backend = ets_backend
         self.remove_pyqt_inputhook = remove_pyqt_inputhook
+        self.ignore_sip_setapi_errors = ignore_sip_setapi_errors
         self.umd_enabled = umd_enabled
         self.umd_namelist = umd_namelist
         self.umd_verbose = umd_verbose
@@ -231,16 +232,16 @@ class ExternalPythonShell(ExternalShellBase):
         if self.namespacebrowser_button is None \
            and self.stand_alone is not None:
             self.namespacebrowser_button = create_toolbutton(self,
-                          text=self.tr("Variables"),
+                          text=_("Variables"),
                           icon=get_icon('dictedit.png'),
-                          tip=self.tr("Show/hide global variables explorer"),
+                          tip=_("Show/hide global variables explorer"),
                           toggled=self.toggle_globals_explorer,
                           text_beside_icon=True)
         if self.terminate_button is None:
             self.terminate_button = create_toolbutton(self,
-                          text=self.tr("Terminate"),
+                          text=_("Terminate"),
                           icon=get_icon('terminate.png'),
-                          tip=self.tr("Attempts to terminate the process.\n"
+                          tip=_("Attempts to terminate the process.\n"
                                       "The process may not exit as a result of "
                                       "clicking this button\n"
                                       "(it is given the chance to prompt "
@@ -254,24 +255,24 @@ class ExternalPythonShell(ExternalShellBase):
 
     def get_options_menu(self):
         ExternalShellBase.get_options_menu(self)
-        self.interact_action = create_action(self, self.tr("Interact"))
+        self.interact_action = create_action(self, _("Interact"))
         self.interact_action.setCheckable(True)
-        self.debug_action = create_action(self, self.tr("Debug"))
+        self.debug_action = create_action(self, _("Debug"))
         self.debug_action.setCheckable(True)
-        self.args_action = create_action(self, self.tr("Arguments..."),
+        self.args_action = create_action(self, _("Arguments..."),
                                          triggered=self.get_arguments)
-        run_settings_menu = QMenu(self.tr("Run settings"), self)
+        run_settings_menu = QMenu(_("Run settings"), self)
         add_actions(run_settings_menu,
                     (self.interact_action, self.debug_action, self.args_action))
-        self.cwd_button = create_action(self, self.tr("Working directory"),
+        self.cwd_button = create_action(self, _("Working directory"),
                                 icon=get_std_icon('DirOpenIcon'),
-                                tip=self.tr("Set current working directory"),
+                                tip=_("Set current working directory"),
                                 triggered=self.set_current_working_directory)
-        self.env_button = create_action(self, self.tr("Environment variables"),
+        self.env_button = create_action(self, _("Environment variables"),
                                         icon=get_icon('environ.png'),
                                         triggered=self.show_env)
         self.syspath_button = create_action(self,
-                                            self.tr("Show sys.path contents"),
+                                            _("Show sys.path contents"),
                                             icon=get_icon('syspath.png'),
                                             triggered=self.show_syspath)
         actions = [run_settings_menu, self.show_time_action, None,
@@ -318,11 +319,11 @@ class ExternalPythonShell(ExternalShellBase):
                                     (not self.interpreter or self.ipython))
         if state:
             if self.arguments:
-                argstr = self.tr("Arguments: %1").arg(self.arguments)
+                argstr = _("Arguments: %s") % self.arguments
             else:
-                argstr = self.tr("No argument")
+                argstr = _("No argument")
         else:
-            argstr = self.tr("Arguments...")
+            argstr = _("Arguments...")
         self.args_action.setText(argstr)
         self.terminate_button.setVisible(not self.interpreter and state)
         if not state:
@@ -412,6 +413,8 @@ class ExternalPythonShell(ExternalShellBase):
         env.append('MATPLOTLIB_PATCH=%r' % self.mpl_patch_enabled)
         env.append('MATPLOTLIB_BACKEND=%s' % self.mpl_backend)
         env.append('REMOVE_PYQT_INPUTHOOK=%s' % self.remove_pyqt_inputhook)
+        env.append('IGNORE_SIP_SETAPI_ERRORS=%s'
+                   % self.ignore_sip_setapi_errors)
         
         # User Module Deleter
         if self.interpreter:
@@ -468,8 +471,8 @@ class ExternalPythonShell(ExternalShellBase):
         running = self.process.waitForStarted()
         self.set_running_state(running)
         if not running:
-            QMessageBox.critical(self, self.tr("Error"),
-                                 self.tr("Process failed to start"))
+            QMessageBox.critical(self, _("Error"),
+                                 _("Process failed to start"))
         else:
             self.shell.setFocus()
             self.emit(SIGNAL('started()'))
@@ -534,7 +537,7 @@ class ExternalPythonShell(ExternalShellBase):
         cwd = self.shell.get_cwd()
         self.emit(SIGNAL('redirect_stdio(bool)'), False)
         directory = QFileDialog.getExistingDirectory(self,
-                                             self.tr("Select directory"), cwd)
+                                                _("Select directory"), cwd)
         if not directory.isEmpty():
             self.shell.set_cwd(unicode(directory))
         self.emit(SIGNAL('redirect_stdio(bool)'), True)
@@ -547,7 +550,7 @@ class ExternalPythonShell(ExternalShellBase):
         
     def show_syspath(self):
         """Show sys.path contents"""
-        self.dialog_manager.show(DictEditor(self.shell.get_syspath(),
-                                            title="sys.path",
-                                            width=600, icon='syspath.png',
-                                            readonly=True))
+        editor = DictEditor()
+        editor.setup(self.shell.get_syspath(), title="sys.path", readonly=True,
+                     width=600, icon='syspath.png')
+        self.dialog_manager.show(editor)
