@@ -3,7 +3,7 @@
 formlayout
 ==========
 
-Module creating PyQt4 form dialogs/layouts to edit various type of parameters
+Module creating Qt form dialogs/layouts to edit various type of parameters
 
 
 formlayout License Agreement (MIT License)
@@ -47,20 +47,24 @@ import sys
 STDERR = sys.stderr
 
 try:
-    from PyQt4.QtGui import QFormLayout
+    from spyderlib.qt.QtGui import QFormLayout
 except ImportError:
     raise ImportError, "Warning: formlayout requires PyQt4 >v4.3"
 
-from PyQt4.QtGui import (QWidget, QLineEdit, QComboBox, QLabel, QSpinBox, QIcon,
-                         QStyle, QDialogButtonBox, QHBoxLayout, QVBoxLayout,
-                         QDialog, QColor, QPushButton, QCheckBox, QColorDialog,
-                         QPixmap, QTabWidget, QApplication, QStackedWidget,
-                         QDateEdit, QDateTimeEdit, QFont, QFontComboBox,
-                         QFontDatabase, QGridLayout, QDoubleValidator)
-from PyQt4.QtCore import (Qt, SIGNAL, SLOT, QSize, QString,
-                          pyqtSignature, pyqtProperty)
+from spyderlib.qt.QtGui import (QWidget, QLineEdit, QComboBox, QLabel,
+                                QSpinBox, QIcon, QStyle, QDialogButtonBox,
+                                QHBoxLayout, QVBoxLayout, QDialog, QColor,
+                                QPushButton, QCheckBox, QColorDialog, QPixmap,
+                                QTabWidget, QApplication, QStackedWidget,
+                                QDateEdit, QDateTimeEdit, QFont, QFontComboBox,
+                                QFontDatabase, QGridLayout, QDoubleValidator)
+from spyderlib.qt.QtCore import (Qt, SIGNAL, SLOT, QSize, QString,
+                                 pyqtSignature, pyqtProperty)
 import datetime
 
+# Local imports
+from spyderlib.config import _
+
 
 class ColorButton(QPushButton):
     """
@@ -197,12 +201,12 @@ class FontLayout(QGridLayout):
         self.addWidget(self.size, 1, 0)
         
         # Italic or not
-        self.italic = QCheckBox(self.tr("Italic"), parent)
+        self.italic = QCheckBox(_("Italic"), parent)
         self.italic.setChecked(font.italic())
         self.addWidget(self.italic, 1, 1)
         
         # Bold or not
-        self.bold = QCheckBox(self.tr("Bold"), parent)
+        self.bold = QCheckBox(_("Bold"), parent)
         self.bold.setChecked(font.bold())
         self.addWidget(self.bold, 1, 2)
         
