@@ -5,10 +5,10 @@
 # (see spyderlib/__init__.py for details)
 
 """
-Object Editor Dialog based on PyQt4
+Object Editor Dialog based on Qt
 """
 
-from PyQt4.QtCore import QObject, SIGNAL
+from spyderlib.qt.QtCore import QObject, SIGNAL
 
 class DialogKeeper(QObject):
     def __init__(self):
@@ -58,9 +58,8 @@ def oedit(obj, modal=True, namespace=None):
                                               Image, is_known_type)
     from spyderlib.widgets.arrayeditor import ArrayEditor
     
-    from spyderlib.utils.qthelpers import qapplication, install_translators
+    from spyderlib.utils.qthelpers import qapplication
     app = qapplication()
-    install_translators(app)
     
     if modal:
         obj_name = ''
@@ -92,7 +91,8 @@ def oedit(obj, modal=True, namespace=None):
     elif isinstance(obj, (str, unicode)):
         dialog = TextEditor(obj, title=obj_name, readonly=readonly)
     elif isinstance(obj, (dict, tuple, list)):
-        dialog = DictEditor(obj, title=obj_name, readonly=readonly)
+        dialog = DictEditor()
+        dialog.setup(obj, title=obj_name, readonly=readonly)
     else:
         raise RuntimeError("Unsupported datatype")
     
