@@ -6,10 +6,10 @@
 
 """Shell widgets: base, python and terminal"""
 
-# pylint: disable-msg=C0103
-# pylint: disable-msg=R0903
-# pylint: disable-msg=R0911
-# pylint: disable-msg=R0201
+# pylint: disable=C0103
+# pylint: disable=R0903
+# pylint: disable=R0911
+# pylint: disable=R0201
 
 import sys, os, time, os.path as osp, re
 
@@ -95,7 +95,7 @@ class ShellBaseWidget(ConsoleBaseWidget):
         self.setCursorWidth( CONF.get('shell_appearance', 'cursor/width') )
         
     def toggle_wrap_mode(self, enable):
-        """Reimplement ConsoleBaseWidget method: 'word' -> 'character'"""
+        """Enable/disable wrap mode"""
         self.set_wrap_mode('character' if enable else None)
 
     def set_font(self, font):
