@@ -6,17 +6,17 @@
 
 """QPlainTextEdit base class"""
 
-# pylint: disable-msg=C0103
-# pylint: disable-msg=R0903
-# pylint: disable-msg=R0911
-# pylint: disable-msg=R0201
+# pylint: disable=C0103
+# pylint: disable=R0903
+# pylint: disable=R0911
+# pylint: disable=R0201
 
 import sys, re, string, os
 
 from spyderlib.qt.QtGui import (QTextCursor, QColor, QFont, QApplication,
                                 QTextEdit, QTextCharFormat, QToolTip,
                                 QTextDocument, QListWidget, QPlainTextEdit,
-                                QPalette, QMainWindow)
+                                QPalette, QMainWindow, QTextOption)
 from spyderlib.qt.QtCore import (QPoint, SIGNAL, Qt, QRegExp, QString,
                                  QEventLoop)
 
@@ -39,9 +39,6 @@ class CompletionWidget(QListWidget):
         self.case_sensitive = False
         self.show_single = None
         self.enter_select = None
-        desktop = QApplication.desktop()
-        srect = desktop.availableGeometry(desktop.screenNumber(self))
-        self.screen_size = (srect.width(), srect.height())
         self.hide()
         self.connect(self, SIGNAL("itemActivated(QListWidgetItem*)"),
                      self.item_selected)
@@ -65,17 +62,33 @@ class CompletionWidget(QListWidget):
         self.setFocus()
         self.raise_()
         
+        # Retrieving current screen height
+        desktop = QApplication.desktop()
+        srect = desktop.availableGeometry(desktop.screenNumber(self))
+        screen_height = srect.height()
+        
         point = self.textedit.cursorRect().bottomRight()
         point.setX(point.x()+self.textedit.get_linenumberarea_width())
         point = self.textedit.mapToGlobal(point)
-        if self.screen_size[1]-point.y()-self.height() < 0:
+        
+        # Computing completion widget and its parent bottom positions
+        comp_bottom = point.y()+self.height()
+        ancestor = self.parent()
+        if ancestor is None:
+            anc_bottom = screen_height
+        else:
+            anc_bottom = min([ancestor.y()+ancestor.height(), screen_height])
+        
+        # Moving completion widget above if there is not enough space below
+        if comp_bottom > anc_bottom:
             point = self.textedit.cursorRect().topRight()
             point.setX(point.x()+self.textedit.get_linenumberarea_width())
             point = self.textedit.mapToGlobal(point)
             point.setY(point.y()-self.height())
-        if self.parent() is not None:
+            
+        if ancestor is not None:
             # Useful only if we set parent to 'ancestor' in __init__
-            point = self.parent().mapFromGlobal(point)
+            point = ancestor.mapFromGlobal(point)
         self.move(point)
         
         if unicode(self.textedit.completion_text):
@@ -157,13 +170,14 @@ class TextEditBaseWidget(QPlainTextEdit):
         self.eol_chars = None
         
         # Code completion / calltips
-        mainwin = parent
-        while not isinstance(mainwin, QMainWindow):
-            mainwin = mainwin.parent()
-            if mainwin is None:
-                break
-        if mainwin is not None:
-            parent = mainwin
+        if parent is not None:
+            mainwin = parent
+            while not isinstance(mainwin, QMainWindow):
+                mainwin = mainwin.parent()
+                if mainwin is None:
+                    break
+            if mainwin is not None:
+                parent = mainwin
         self.completion_widget = CompletionWidget(self, parent)
         self.codecompletion_auto = False
         self.codecompletion_case = True
@@ -344,17 +358,13 @@ class TextEditBaseWidget(QPlainTextEdit):
         Set wrap mode
         Valid *mode* values: None, 'word', 'character'
         """
-        wrap_mode = QPlainTextEdit.NoWrap
-        #XXX: no word/character wrapping in QPlainTextEdit
         if mode == 'word':
-            wrap_mode = QPlainTextEdit.WidgetWidth
+            wrap_mode = QTextOption.WrapAtWordBoundaryOrAnywhere
         elif mode == 'character':
-            wrap_mode = QPlainTextEdit.WidgetWidth
-        self.setLineWrapMode(wrap_mode)
-
-    def toggle_wrap_mode(self, enable):
-        """Enable/disable wrap mode"""
-        self.set_wrap_mode('word' if enable else None)
+            wrap_mode = QTextOption.WrapAnywhere
+        else:
+            wrap_mode = QTextOption.NoWrap
+        self.setWordWrapMode(wrap_mode)
         
         
     #------Positions, coordinates (cursor, EOF, ...)
