@@ -8,10 +8,10 @@
 Editor widget based on QtGui.QPlainTextEdit
 """
 
-# pylint: disable-msg=C0103
-# pylint: disable-msg=R0903
-# pylint: disable-msg=R0911
-# pylint: disable-msg=R0201
+# pylint: disable=C0103
+# pylint: disable=R0903
+# pylint: disable=R0911
+# pylint: disable=R0201
 
 from __future__ import division
 
@@ -23,7 +23,7 @@ from spyderlib.qt.QtGui import (QMouseEvent, QColor, QMenu, QApplication,
                                 QTextDocument, QTextCharFormat, QPixmap,
                                 QPrinter, QToolTip, QCursor, QInputDialog,
                                 QTextBlockUserData, QLineEdit, QShortcut,
-                                QKeySequence, QWidget)
+                                QKeySequence, QWidget, QKeyEvent)
 from spyderlib.qt.QtCore import (Qt, SIGNAL, QString, QEvent, QTimer, QRect,
                                  QRegExp, PYQT_VERSION_STR, QVariant, QSize)
 
@@ -104,7 +104,7 @@ class EdgeLine(QWidget):
     def __init__(self, editor):
         QWidget.__init__(self, editor)
         self.code_editor = editor
-        self.column = 80
+        self.column = 79
         
     def paintEvent(self, event):
         painter = QPainter(self)
@@ -362,6 +362,11 @@ class CodeEditor(TextEditBaseWidget):
         self.highlighter = editor.highlighter
         self._apply_highlighter_color_scheme()
         
+    #-----Widget setup and options
+    def toggle_wrap_mode(self, enable):
+        """Enable/disable wrap mode"""
+        self.set_wrap_mode('word' if enable else None)
+        
     def setup_editor(self, linenumbers=True, language=None, code_analysis=False,
                      font=None, color_scheme=None, wrap=False, tab_mode=True,
                      intelligent_backspace=True, highlight_current_line=True,
@@ -1535,13 +1540,22 @@ class CodeEditor(TextEditBaseWidget):
             self.__clear_occurences()
         if QToolTip.isVisible():
             self.hide_tooltip_if_necessary(key)
-        if key in (Qt.Key_Enter, Qt.Key_Return) and not shift and not ctrl:
-            if self.is_completion_widget_visible() \
-               and self.codecompletion_enter:
-                self.select_completion_list()
-            else:
+        if key in (Qt.Key_Enter, Qt.Key_Return):
+            if not shift and not ctrl:
+                if self.is_completion_widget_visible() \
+                   and self.codecompletion_enter:
+                    self.select_completion_list()
+                else:
+                    QPlainTextEdit.keyPressEvent(self, event)
+                    self.fix_indent()
+            elif shift:
+                # Ignoring QPlainTextEdit default Shift+Enter keybinding 
+                # which will print a new line in the same block:
+                event = QKeyEvent(event.type(), event.key(), Qt.NoModifier,
+                                  event.text(), event.isAutoRepeat(),
+                                  event.count())
                 QPlainTextEdit.keyPressEvent(self, event)
-                self.fix_indent()
+                return
         elif key == Qt.Key_Insert and not shift and not ctrl:
             self.setOverwriteMode(not self.overwriteMode())
         elif key == Qt.Key_Backspace and not shift and not ctrl:
